##############################################
# R script illustrating the use of goodness-
# of-fit functions for co-evolution models;
# builds on results of "lab-coevolution.R".
# version of 5 February 2017
# written by Christian Steglich
##############################################

# first load namespace and results from previous script:
library(RSiena)
load('CoEvolutionResults.RData')

# specify options for the simulation algorithm:
simulation.options <- sienaAlgorithmCreate(useStdInits=FALSE,cond=FALSE,
	n3=250,nsub=0,MaxDegree=c(friendship=6),seed=1234567)

# add simulated networks & behaviour to model results:
sim.results <- siena07(simulation.options,data=CoEvolutionData,
	effects=CoEvolutionModel,batch=FALSE,verbose=FALSE,returnDeps=TRUE,
	prevAns=CoEvolutionResults)

# check how the first simulated dataset looks like:
sim.results$sims[[1]]

# For familiarity, let's first inspect network goodness-of-fit.

# goodness of fit for indegree distribution:
gof.indegrees <- sienaGOF(sim.results,IndegreeDistribution,
	verbose=TRUE,join=TRUE,varName="friendship",cumulative=FALSE)
gof.indegrees
plot(gof.indegrees) # looks good enough

# goodness of fit for outdegree distribution:
gof.outdegrees <- sienaGOF(sim.results,OutdegreeDistribution,
	verbose=TRUE,join=TRUE,varName="friendship",cumulative=FALSE)
gof.outdegrees
plot(gof.outdegrees) # also okay

# import some custom-made network fit functions:
source("sienaGOF-auxiliary.R")
# note that they require packages 'network' and 'sna'

# goodness of fit for triad census:
gof.triads <- sienaGOF(sim.results,TriadCensus,
	verbose=TRUE,join=TRUE,varName="friendship")
gof.triads
plot(gof.triads,center=TRUE,scale=TRUE) # looks reasonable; some bad triads

# goodness of fit for geodesic distances:
gof.geodesic <- sienaGOF(sim.results,GeodesicDistribution,
	verbose=TRUE,join=TRUE,varName="friendship",cumulative=FALSE)
gof.geodesic
plot(gof.geodesic) # not good, as can be expected

# Now behaviour goodness-of-fit

# goodness of fit overall behaviour distribution:
gof.behaviour <- sienaGOF(sim.results,BehaviorDistribution,
	verbose=TRUE,join=TRUE,varName="drinking",cumulative=FALSE)
gof.behaviour
plot(gof.behaviour) # looks very good!

# import more custom-made fit functions:
source("sienaGOF-coevolution.R")
# they again require packages 'network' and 'sna'

# two spatial autocorrelation coefficients:
gof.MoranGeary <- sienaGOF(sim.results,MoranGeary,
	verbose=TRUE,join=FALSE,varName=c("friendship","drinking"))
# note that we now used option "join=FALSE", which will allow
# checking if GOF is different for the two periods under analysis
gof.MoranGeary
plot(gof.MoranGeary,period=1) # acceptable
plot(gof.MoranGeary,period=2) # acceptable

# Moran's I autocorrelation at a distance: 
gof.Moran <- sienaGOF(sim.results,Moran123,
	verbose=TRUE,join=TRUE,varName=c("friendship","drinking"))
gof.Moran
plot(gof.Moran) # acceptable
# note that periods are aggregated again, and coefficients now
# are summed up over periods (hence the "double range" of values)

# same for Geary's c:
gof.Geary <- sienaGOF(sim.results,Geary123,
	verbose=TRUE,join=TRUE,varName=c("friendship","drinking"))
gof.Geary
plot(gof.Geary)	# acceptable
# note that again coefficients are summed up over periods!

# ego-by-alter table for alcohol scores:
gof.EgoAlterTable <- sienaGOF(sim.results,EgoAlterTable,
	verbose=TRUE,join=TRUE,varName=c("friendship","drinking"))
gof.EgoAlterTable
plot(gof.EgoAlterTable)	
# For this, we should probably have run more than 250 simulations
